#!/bin/bash

# run as: ./makegs2.sh
# or ./makegs2.sh gnome-lib to compile GS2 using gnome-lib 
# which checks out gnome-lib src from svn if needed and if possible

docheckout=$1
getimagick=$2
gsdlhome=`pwd`
echo "**** GSDLHOME: $gsdlhome"

bitness=`uname -m`
# if we're 64 bit, add -fPIC to CFLAGS. Check if bitness contains substring "64"
if [[ $bitness == *"64"* ]]; then
  export CFLAGS="-fPIC $CFLAGS"
  echo "64 bit unix system, incl -fPIC in CFLAGS so it is now: $CFLAGS"
fi

# Compile by chaining the commands with && so it stops at that stage after an error
cd $gsdlhome
if [ "x$docheckout" = "xgnome-lib" ]; then
    ./configure --enable-gnome-lib-ext --enable-apache-httpd \
	&& make \
	&& make install
else
    ./configure --enable-apache-httpd \
	&& make \
	&& make install
fi

status=$?
echo "****************************************"
if [ $status = 0 ] ; then
    # 5. Message to warn user that the env of this x-term uses gnome-lib 
    # and GUIs may not work from this console
    if [ "x$docheckout" = "xgnome-lib" ]; then
	echo "*** The environment for this console has been set to compile Greenstone with gnome-lib."
	echo "*** As a result, graphical applications may not work well."
	echo "*** In such a case, open a new console."
    else
	echo "Finished compiling Greenstone2. (Compiled without gnome-lib)"
    fi
else
    echo "@@@ Error compiling up Greenstone. Return status: $status"
fi
if [[ $bitness == *"64"* ]]; then
    echo ""
    echo "This unix is 64 bit. So added -fPIC to CFLAGS, which is now: $CFLAGS"
fi
echo "****************************************"    


imgpkg=
if [ "x$getimagick" = "ximagemagick" ]; then
   os=`uname`

   if [ "x$os" = "xDarwin" ]; then
       # by default, resort to the Mac Leopard (10.5, kernel 12.6.0)'s imagemagick binary
       imgpkg=http://trac.greenstone.org/export/head/gs2-extensions/imagemagick/trunk/imagemagick-darwin-10.5.tar.gz

       kernelVersion=`uname -r`
       # El Capitan is MacOS version 10.11 but its kernelVersion is 15.6.0
       if [ "x$kernelVersion" = "x15.6.0" ]; then
	   echo "Getting imagemagick built for El Capitan"
	   imgpkg=http://trac.greenstone.org/export/head/gs2-extensions/imagemagick/trunk/imagemagick-darwin-10.11.tar.gz
       else
	   echo "Getting imagemagick built on Mac Leopard"
       fi

       pushd ext
       curl $imgpkg > imagemagick.tar.gz
       tar -xvzf imagemagick.tar.gz
       mv imagemagick/darwin ../bin/darwin/imagemagick
       popd

   else
       # linux
       pushd ext
       if [[ $bitness == *"64"* ]]; then
	   echo "Getting 64 bit imagemagick precompiled binary"
	   wget http://trac.greenstone.org/export/head/gs2-extensions/imagemagick/trunk/imagemagick-linux-x64.tar.gz
	   tar -xvzf imagemagick-linux-x64.tar.gz
       else
	   echo "Getting 32 bit imagemagick precompiled binary"
	   wget http://trac.greenstone.org/export/head/gs2-extensions/imagemagick/trunk/imagemagick-linux.tar.gz
	   tar -xvzf imagemagick-linux.tar.gz
       fi

       mv imagemagick/linux ../bin/linux/imagemagick
       popd
   fi
   
fi
